@@ -35,7 +35,7 @@
 #include "query.h"
 #include "geometry.h"
 
-void query_tree(FILE *rsp)
+void query_state(FILE *rsp)
 {
 	fprintf(rsp, "{");
 	fprintf(rsp, "\"focusedMonitorId\":%u,", mon->id);
@@ -58,8 +58,12 @@ void query_tree(FILE *rsp)
 	fprintf(rsp,",");
 	fprintf(rsp, "\"stackingList\":");
 	query_stack(rsp);
+	if (restart) {
+		fprintf(rsp,",");
+		fprintf(rsp, "\"eventSubscribers\":");
+		query_subscribers(rsp);
+	}
 	fprintf(rsp, "}");
-
 }
 
 void query_monitor(monitor_t *m, FILE *rsp)
@@ -97,6 +101,7 @@ void query_desktop(desktop_t *d, FILE *rsp)
 	fprintf(rsp, "\"name\":\"%s\",", d->name);
 	fprintf(rsp, "\"id\":%u,", d->id);
 	fprintf(rsp, "\"layout\":\"%s\",", LAYOUT_STR(d->layout));
+	fprintf(rsp, "\"userLayout\":\"%s\",", LAYOUT_STR(d->user_layout));
 	fprintf(rsp, "\"windowGap\":%i,", d->window_gap);
 	fprintf(rsp, "\"borderWidth\":%u,", d->border_width);
 	fprintf(rsp, "\"focusedNodeId\":%u,", d->focus != NULL ? d->focus->id : 0);
@@ -117,7 +122,6 @@ void query_node(node_t *n, FILE *rsp)
 		fprintf(rsp, "\"id\":%u,", n->id);
 		fprintf(rsp, "\"splitType\":\"%s\",", SPLIT_TYPE_STR(n->split_type));
 		fprintf(rsp, "\"splitRatio\":%lf,", n->split_ratio);
-		fprintf(rsp, "\"birthRotation\":%i,", n->birth_rotation);
 		fprintf(rsp, "\"vacant\":%s,", BOOL_STR(n->vacant));
 		fprintf(rsp, "\"hidden\":%s,", BOOL_STR(n->hidden));
 		fprintf(rsp, "\"sticky\":%s,", BOOL_STR(n->sticky));
@@ -222,6 +226,22 @@ void query_stack(FILE *rsp)
 	fprintf(rsp, "]");
 }
 
+void query_subscribers(FILE *rsp)
+{
+	fprintf(rsp, "[");
+	for (subscriber_list_t *s = subscribe_head; s != NULL; s = s->next) {
+		fprintf(rsp, "{\"fileDescriptor\": %i", fileno(s->stream));
+		if (s->fifo_path != NULL) {
+			fprintf(rsp, ",\"fifoPath\":\"%s\"", s->fifo_path);
+		}
+		fprintf(rsp, ",\"field\":%i,\"count\":%i}", s->field, s->count);
+		if (s->next != NULL) {
+			fprintf(rsp, ",");
+		}
+	}
+	fprintf(rsp, "]");
+}
+
 int query_node_ids(coordinates_t *ref, coordinates_t *trg, node_select_t *sel, FILE *rsp)
 {
 	int count = 0;
@@ -431,8 +451,8 @@ node_select_t make_node_select(void)
 	node_select_t sel = {
 		.automatic = OPTION_NONE,
 		.focused = OPTION_NONE,
-		.local = OPTION_NONE,
 		.active = OPTION_NONE,
+		.local = OPTION_NONE,
 		.leaf = OPTION_NONE,
 		.window = OPTION_NONE,
 		.tiled = OPTION_NONE,
@@ -460,6 +480,7 @@ desktop_select_t make_desktop_select(void)
 	desktop_select_t sel = {
 		.occupied = OPTION_NONE,
 		.focused = OPTION_NONE,
+		.active = OPTION_NONE,
 		.urgent = OPTION_NONE,
 		.local = OPTION_NONE
 	};
@@ -482,13 +503,17 @@ int node_from_desc(char *desc, coordinates_t *ref, coordinates_t *dst)
 	char *desc_copy = copy_string(desc, strlen(desc));
 	desc = desc_copy;
 
-	char *hash = NULL;
+	char *hash = strrchr(desc, '#');
 	char *path = strrchr(desc, '@');
-	if (path == NULL) {
-		hash = strrchr(desc, '#');
-	} else {
-		if (path != desc && *(path - 1) == '#') {
+	char *colon = strrchr(desc, ':');
+
+	/* Discard hashes inside a DESKTOP_SEL */
+	if (hash != NULL && colon != NULL && path != NULL &&
+	    path < hash && hash < colon) {
+		if (path > desc && *(path - 1) == '#') {
 			hash = path - 1;
+		} else {
+			hash = NULL;
 		}
 	}
 
@@ -505,7 +530,6 @@ int node_from_desc(char *desc, coordinates_t *ref, coordinates_t *dst)
 	}
 
 	node_select_t sel = make_node_select();
-	char *colon = strrchr(desc, ':');
 
 	if (!parse_node_modifiers(colon != NULL ? colon : desc, &sel)) {
 		free(desc_copy);
@@ -530,7 +554,9 @@ int node_from_desc(char *desc, coordinates_t *ref, coordinates_t *dst)
 	} else if (streq("newest", desc)) {
 		history_find_newest_node(ref, dst, &sel);
 	} else if (streq("biggest", desc)) {
-		find_biggest(ref, dst, &sel);
+		find_by_area(AREA_BIGGEST, ref, dst, &sel);
+	} else if (streq("smallest", desc)) {
+		find_by_area(AREA_SMALLEST, ref, dst, &sel);
 	} else if (streq("pointed", desc)) {
 		xcb_window_t win = XCB_NONE;
 		query_pointer(&win, NULL);
@@ -980,12 +1006,19 @@ bool node_matches(coordinates_t *loc, coordinates_t *ref, node_select_t *sel)
 	}
 
 	if (sel->focused != OPTION_NONE &&
-	    loc->node != loc->desktop->focus
+	    loc->node != mon->desk->focus
 	    ? sel->focused == OPTION_TRUE
 	    : sel->focused == OPTION_FALSE) {
 		return false;
 	}
 
+	if (sel->active != OPTION_NONE &&
+	    loc->node != loc->desktop->focus
+	    ? sel->active == OPTION_TRUE
+	    : sel->active == OPTION_FALSE) {
+		return false;
+	}
+
 	if (sel->automatic != OPTION_NONE &&
 	    loc->node->presel != NULL
 	    ? sel->automatic == OPTION_TRUE
@@ -1118,12 +1151,19 @@ bool desktop_matches(coordinates_t *loc, coordinates_t *ref, desktop_select_t *s
 	}
 
 	if (sel->focused != OPTION_NONE &&
-	    loc->desktop != loc->monitor->desk
+	    loc->desktop != mon->desk
 	    ? sel->focused == OPTION_TRUE
 	    : sel->focused == OPTION_FALSE) {
 		return false;
 	}
 
+	if (sel->active != OPTION_NONE &&
+	    loc->desktop != loc->monitor->desk
+	    ? sel->active == OPTION_TRUE
+	    : sel->active == OPTION_FALSE) {
+		return false;
+	}
+
 	if (sel->urgent != OPTION_NONE &&
 	    !is_urgent(loc->desktop)
 	    ? sel->urgent == OPTION_TRUE
@@ -1151,7 +1191,7 @@ bool monitor_matches(coordinates_t *loc, __attribute__((unused)) coordinates_t *
 	}
 
 	if (sel->focused != OPTION_NONE &&
-	    mon != loc->monitor
+	    loc->monitor != mon
 	    ? sel->focused == OPTION_TRUE
 	    : sel->focused == OPTION_FALSE) {
 		return false;
