@@ -44,7 +44,7 @@ enum {
 typedef void (*monitor_printer_t)(monitor_t *m, FILE *rsp);
 typedef void (*desktop_printer_t)(desktop_t *m, FILE *rsp);
 
-void query_tree(FILE *rsp);
+void query_state(FILE *rsp);
 void query_monitor(monitor_t *m, FILE *rsp);
 void query_desktop(desktop_t *d, FILE *rsp);
 void query_node(node_t *n, FILE *rsp);
@@ -56,6 +56,7 @@ void query_padding(padding_t p, FILE *rsp);
 void query_history(FILE *rsp);
 void query_coordinates(coordinates_t *loc, FILE *rsp);
 void query_stack(FILE *rsp);
+void query_subscribers(FILE *rsp);
 int query_node_ids(coordinates_t *ref, coordinates_t *trg, node_select_t *sel, FILE *rsp);
 int query_node_ids_in(node_t *n, desktop_t *d, monitor_t *m, coordinates_t *ref, coordinates_t *trg, node_select_t *sel, FILE *rsp);
 int query_desktop_ids(coordinates_t *ref, coordinates_t *trg, desktop_select_t *sel, desktop_printer_t printer, FILE *rsp);
