@@ -53,22 +53,25 @@ void load_settings(void)
 	snprintf(presel_feedback_color, sizeof(presel_feedback_color), "%s", PRESEL_FEEDBACK_COLOR);
 
 	padding = (padding_t) PADDING;
+	monocle_padding = (padding_t) MONOCLE_PADDING;
 	window_gap = WINDOW_GAP;
 	border_width = BORDER_WIDTH;
 	split_ratio = SPLIT_RATIO;
-	initial_polarity = FIRST_CHILD;
+	initial_polarity = SECOND_CHILD;
+	automatic_scheme = AUTOMATIC_SCHEME;
+	removal_adjustment = REMOVAL_ADJUSTMENT;
 	directional_focus_tightness = TIGHTNESS_HIGH;
+
 	pointer_modifier = POINTER_MODIFIER;
 	pointer_motion_interval = POINTER_MOTION_INTERVAL;
-	mapping_events_count = MAPPING_EVENTS_COUNT;
-
 	pointer_actions[0] = ACTION_MOVE;
 	pointer_actions[1] = ACTION_RESIZE_SIDE;
 	pointer_actions[2] = ACTION_RESIZE_CORNER;
+	mapping_events_count = MAPPING_EVENTS_COUNT;
 
+	presel_feedback = PRESEL_FEEDBACK;
 	borderless_monocle = BORDERLESS_MONOCLE;
 	gapless_monocle = GAPLESS_MONOCLE;
-	paddingless_monocle = PADDINGLESS_MONOCLE;
 	single_monocle = SINGLE_MONOCLE;
 
 	focus_follows_pointer = FOCUS_FOLLOWS_POINTER;
@@ -78,6 +81,7 @@ void load_settings(void)
 	swallow_first_click = SWALLOW_FIRST_CLICK;
 	ignore_ewmh_focus = IGNORE_EWMH_FOCUS;
 	ignore_ewmh_fullscreen = IGNORE_EWMH_FULLSCREEN;
+	ignore_ewmh_struts = IGNORE_EWMH_STRUTS;
 
 	center_pseudo_tiled = CENTER_PSEUDO_TILED;
 	honor_size_hints = HONOR_SIZE_HINTS;
